import { Injectable } from '@angular/core';
import { User } from '../../../model/User';
import { AuthService } from '../auth/auth.service';
import { AngularFirestore } from '@angular/fire/compat/firestore';

@Injectable({
  providedIn: 'root'
})
export class UserService {
  constructor(private auth: AuthService, private afs: AngularFirestore) { }

  getUser(username: String): Promise<User> {
    return new Promise<User>((resolve, reject) => {
      if (this.auth.checkAllowed()) {
        if (username != undefined) {
          this.afs.collection<User>('user').doc(username as string).valueChanges().subscribe(data => { resolve(data as User) });
        } else {
          this.auth.getUser().subscribe(cred => {
            this.afs.collection<User>('user', ref => ref.where('id', '==', cred?.uid)).valueChanges().subscribe(user => { resolve(user[0]) })
          });
        }
      } else {
        reject();
      }
    });
  }

  getCurrentUser(): Promise<User> {
    return new Promise<User>((resolve, reject) => {
      this.auth.getUser().subscribe(user => {
        this.afs.collection<User>('user', ref => ref.where('id', '==', user?.uid)).valueChanges().subscribe(users => {
          if (users.length != 0)
            resolve(users[0]);
          else
            reject();
        })
      });
    });
  }

  createUser(username: String, email: String, id: String) {
    return new Promise<void>((resolve, reject) => {
      this.afs.collection('user').doc(username as string).set({
        username: username,
        email: email,
        picture: "/assets/placeholder-profile-picture.png",
        id: id
      });
      resolve();
    });
  }

  searchByUsername(query: String): Promise<Array<User>> {
    return new Promise<Array<User>>((resolve, reject) => {
      this.afs.collection<User>('user').valueChanges().subscribe(users => {
        resolve(users.filter(user => user.username.includes(query as string)));
      })
    });
  }
}
