import { Component, Input, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { SmallUserComponent } from '../small-user/small-user.component';
import { Post } from '../../../../model/Post';
import { NgIf } from '@angular/common';
import { PostService } from '../../../services/data/post.service';
import { UserService } from '../../../services/data/user.service';

@Component({
  selector: 'app-post',
  standalone: true,
  imports: [SmallUserComponent, NgIf, CommonModule],
  templateUrl: './post.component.html',
  styleUrl: './post.component.scss'
})
export class PostComponent implements OnInit {
  @Input() post: Post | undefined;

  isOwned: boolean = false;
  deleted: boolean = false;

  constructor(private userSv: UserService, private postSv: PostService) { }

  ngOnInit(): void {
    this.userSv.getCurrentUser().then(user => {
      this.isOwned = user?.username == this.post?.user.username;
    });
  }

  remove() {
    this.postSv.removePost(this.post?.id as String)
      .then(() => {
        this.deleted = true;
        console.log(this.deleted);
      })
      .catch(() => {
        alert("failed to delete post");
      })
  }

  like() {
    this.postSv.toggleLike(this.post?.id as String)
      .then((result)=>{
        ((this.post as Post).likes as number) += result ? 1 : -1;
        (this.post as Post).liked = result;
      })
      .catch(()=>{alert('failed to toggle like on post')})
  }
}
